@@ -17,11 +17,11 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Index.py,v 1.11.2.5 2000/09/25 08:16:35 fredgo Exp $
+# $Id: Index.py,v 1.11.2.8 2001/12/07 13:24:27 fredgo Exp $
 
 ''' Main index containing the columned view of the entries '''
 
-from Pyblio import Fields, Config, Connector, Types
+from Pyblio import Fields, Config, Connector, Types, Sort
 
 from gnome.ui import *
 from gnome import config
@@ -146,7 +146,15 @@ class Index (Connector.Publisher):
         if info == Mime.ENTRY:
             text = pickle.dumps (self.selection_buffer)
         else:
-            text = join (map (str, self.selection_buffer), '\n\n')
+            if Config.get ('gnome/paste-key').data:
+                # if we want the keys, return the keys !
+                keys = []
+                for e in self.selection_buffer:
+                    keys.append (str (e.key.key))
+                text = join (keys, ',')
+            else:
+                # else, return the full entries
+                text = join (map (str, self.selection_buffer), '\n\n')
         
         selection.set (1, 8, text)
         return
@@ -221,7 +229,7 @@ class Index (Connector.Publisher):
         if type (item) is not type (1):
             item = self.get_item_position (item)
 
-        if item == -1: return
+        if item == -1 or item >= len (self.access): return
         
         self.clist.select_row (item, 0)
         self.set_scroll (item)
@@ -281,6 +289,37 @@ class Index (Connector.Publisher):
         Utils.set_cursor (self.w, 'normal')
         return
 
+
+    def go_to_first (self, query, field):
+        ''' Go to the first entry that matches a key '''
+        if not isinstance (field, Sort.FieldSort): return 0
+
+        f = field.field
+        q = lower (query)
+        l = len (q)
+        i = 0
+        
+        for e in self.access:
+            if not e.has_key (f): continue
+
+            c = cmp (lower (str (e [f])) [0:l], q)
+
+            if c == 0:
+                # matching !
+                self.set_scroll (i)
+                return 1
+
+            if c > 0:
+                # we must be after the entry...
+                self.set_scroll (i)
+                return 0
+            
+            i = i + 1
+
+        # well, show the user its entry must be after the bounds
+        self.set_scroll (i)
+        return  0
+        
     
     def click_column (self, clist, column, * data):
         ''' handler for column title selection '''
