@@ -18,7 +18,7 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: reverse.c,v 1.8.2.5 2001/06/25 16:04:02 fredgo Exp $
+ $Id: reverse.c,v 1.8.2.6 2001/11/28 18:06:30 fredgo Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -106,7 +106,8 @@ author_needs_quotes (gchar * string) {
 
 BibtexField * 
 bibtex_reverse_field (BibtexField * field,
-		      gboolean use_braces) {
+		      gboolean use_braces,
+		      gboolean do_quote) {
 #ifdef USE_RECODE
     BibtexStruct * s;
     gchar * string, * tmp, c;
@@ -154,8 +155,6 @@ bibtex_reverse_field (BibtexField * field,
 	    }
 	}
 
-	tmp = recode_string (request, field->text);
-
 	if (use_braces) {
 	    g_string_append (st, "@preamble{{");
 	}
@@ -163,8 +162,14 @@ bibtex_reverse_field (BibtexField * field,
 	    g_string_append (st, "@preamble{\"");
 	}
 
-	g_string_append (st, tmp);
-	g_free (tmp);
+	if (do_quote) {
+	  tmp = recode_string (request, field->text);
+	  g_string_append (st, tmp);
+	  g_free (tmp);
+	}
+	else {
+	  g_string_append (st, field->text);
+	}
 
 	if (use_braces) {
 	    g_string_append (st, "}}");
